import { select, 
        json,
        csv,
        tsv, 
        geoPath,
        geoEquirectangular,
        scaleOrdinal,
        schemeCategory10,
        zoom,
        event } from 'd3';
import { feature } from 'topojson';

const svg = select('svg');
const width = parseFloat(svg.attr('width'));
const height = +svg.attr('height');
let stateNames = [];
//defining the dimensions of the SVG graphic
const projection = geoEquirectangular()
			.clipExtent([[0,0],[width,height]])
			.center([100, 30])
			.scale(350);

const pathGenerator = geoPath()
		.projection(projection);

const g = svg.append('g');

svg.call(zoom().on('zoom', () => {
	g.attr('transform', event.transform)
}));

//To get json data from my gist
Promise.all([json('https://gist.githubusercontent.com/Shivamaninaidu/be72402dba4cd0f675a7d1a42c05ae27/raw/e86efdbd5cb7ab28d982b8ae08fce448dc6102a1/china%2520map.csv'),
             json('https://gist.githubusercontent.com/Shivamaninaidu/be72402dba4cd0f675a7d1a42c05ae27/raw/e86efdbd5cb7ab28d982b8ae08fce448dc6102a1/china%2520map.csv')
            ]).then(([stateJSON, districtJSON]) => {
	 
  const stateGroup = g.append('g');
  //To perform simplification process to have efficient map
  			
  const states = feature(stateJSON, stateJSON.objects.CHN_adm1);
  
  const colorScale = scaleOrdinal(schemeCategory10);
  
  const statePath = stateGroup.selectAll('path')
    .data(states.features)
  statePath.enter().append('path')
    .attr('class', 'states')
    .attr('d', d => pathGenerator(d))
});
      